<script src="{{ url_for('static', filename='js/calendar.js') }}"></script>
<link href='https://fonts.googleapis.com/css?family=Sofia' rel='stylesheet'>

<body onload="displayCalendar()">
    <div class="flex-container">
        <div id="calendar"></div>
    </div>
</body>

<link rel="stylesheet" href="{{ url_for('static', filename='css/calendar.css') }}">